@@ -10,6 +10,9 @@ gemspec
 group :maintenance, optional: true do
 	gem "bake-gem"
 	gem "bake-modernize"
+	gem "bake-releases"
+	
+	gem "agent-context"
 	
 	gem "utopia-project"
 end
@@ -18,7 +21,9 @@ group :test do
 	gem "sus"
 	gem "covered"
 	gem "decode"
+
 	gem "rubocop"
+	gem "rubocop-socketry"
 	
 	gem "bake-test"
 end
